@@ -496,6 +496,7 @@ CREATE TABLE IF NOT EXISTS `receive` (
   `srcname` varchar(30) NOT NULL default '',
   `srclevel` int(1) NOT NULL default '0',
   `status` int(1) NOT NULL default '0',
+  `smscnum` varchar(32) NOT NULL,
   PRIMARY KEY  (`id`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
 
@@ -597,6 +598,10 @@ CREATE TABLE IF NOT EXISTS `auto_ussd` (
   `re_step2_cmd` varchar(64) NOT NULL,
   `re_step2_ok_r` varchar(64) character set utf8 NOT NULL,
   `auto_reset_remain_enable` tinyint(1) NOT NULL default '0',
+  `auto_ussd_step3` varchar(160) character set utf8 NOT NULL,
+  `auto_ussd_step3_start_r` varchar(160) character set utf8 NOT NULL,
+  `auto_ussd_step4` varchar(160) character set utf8 NOT NULL,
+  `auto_ussd_step4_start_r` varchar(160) character set utf8 NOT NULL,
   PRIMARY KEY  (`id`),
   KEY `prov_id` (`prov_id`,`goip_id`),
   KEY `recharge_ussd1_goip` (`recharge_ussd1_goip`),
