@@ -345,5 +345,17 @@
 
 /*1.21.5 add set cell*/
 	
+/*1.22 
+add 3-4 step USSD auto balance
+add chaeck receive USSD balance
+fixed bug of delete goip group
+*/
+	
+	@$db->updatequery("ALTER TABLE  `auto_ussd` ADD  `auto_ussd_step3` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ,
+ADD  `auto_ussd_step3_start_r` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ,
+ADD  `auto_ussd_step4` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ,
+ADD  `auto_ussd_step4_start_r` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ;");
+
+	@$db->updatequery("ALTER TABLE  `receive` ADD  `smscnum` VARCHAR( 32 ) NOT NULL ;");
 	echo "update done! <a href=''  target=_top>Return</a>";
 ?>
